
    # kraken_init
    Library to initialize python project.

    Ready to publish to pypi or google cloud run. 

    Creates:
    - setup.cfg
    - setup.py
    - README.md
    - LICENSE.txt
    - Dockerfile
    - requirements.txt
    


    ## How to use

    ```
    import kraken_init
    kraken_init.init('kraken_name')

    

    ```


    
    